/**
 * @file
 * Contains burndown.task_edit.js.
 */
(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.burndownTaskEdit = {
    attach: function (context, settings) {
      // Only do setup once.
      $('body').once('setupLogs').each(function () {
        update_log();
      });

      // Make the watch/unwatch task link work.
      $('.watch_list')
        .once('watchListAction')
        .on('click', function (e) {
          // Do not follow the link.
          e.preventDefault();
          e.stopPropagation();

          // Get the link url.
          var url = $(e.target).attr('href');

          // Send a GET.
          $.ajax({
              url: url, 
              method :'GET', 
              success: function(result){
                // Switch the class and url.
                var container = $('.watch_list');
                var my_link = $('.watch_list a');
                var url = my_link.attr('href');

                if (url.includes('remove_from_watchlist')) {
                  my_link.text('Watch this task');
                  url = url.replace('remove_from_watchlist', 'add_to_watchlist');
                  my_link.attr('href', url);
                  container.removeClass('watch').addClass('mute');
                }
                else {
                  my_link.text('Stop watching this task');
                  url = url.replace('add_to_watchlist', 'remove_from_watchlist');
                  my_link.attr('href', url);
                  container.removeClass('mute').addClass('watch');
                }
              },
              error: function (XMLHttpRequest, textStatus, errorThrown) {
                console.log("Watchlist follow/unfollow error.");
              }
          });
        });

      // For modal views of the task edit form,
      // pull log data when the log details container
      // is opened.
      $('body')
        .once('updateLogAction')
        .on('click', '[data-drupal-selector="edit-log"] summary', function (e) {
          update_log('comment');
        });

      // Tabs to control which logs show.
      $('body')
        .once('clickTabsAction')
        .on('click', '.log_tabs a', function (e) {
          // Do not follow the link.
          e.preventDefault();
          e.stopPropagation();

          var log_type = $(e.target).attr('class');
          update_log(log_type);

          if (log_type == 'comment') {
            // Show comment field.
            $('.form-wrapper.add_comment').show();

            // Hide work field.
            $('.form-wrapper.add_work').hide();
          }
          else if (log_type == 'work') {
            // Show work field.
            $('.form-wrapper.add_work').show();

            // Hide comment field.
            $('.form-wrapper.add_comment').hide();
          }
          else {
            // Hide both comment and work fields.
            $('.form-wrapper.add_comment').hide();
            $('.form-wrapper.add_work').hide();
          }
        });

      // Posting a comment.
      $('body')
        .once('postCommentAction')
        .on('click', '.add_comment a.button', function (e) {
          // Do not follow the link.
          e.preventDefault();
          e.stopPropagation();

          // Post data.
          $.ajax({
              url: "/burndown/api/task/add_comment", 
              method :'POST',
              data: { 
                ticket_id: $('#burndown_task_log').data('ticket-id'),
                comment: $('.add_comment .form-item-body textarea').val()
              },
              success: function(result){
                // On success, reload comments and clear the form.
                update_log('comment');
                $('.add_comment .form-item-body textarea').val('');
              },
              error: function (XMLHttpRequest, textStatus, errorThrown) {
                console.log("Could not post comment.");
              }
          });
        });

      // Posting a work log.
      $('body')
        .once('postWorkAction')
        .on('click', '.add_work a.button', function (e) {
          // Do not follow the link.
          e.preventDefault();
          e.stopPropagation();

          // Post data.
          $.ajax({
              url: "/burndown/api/task/add_work", 
              method :'POST',
              data: { 
                ticket_id: $('#burndown_task_log').data('ticket-id'),
                comment: $('.add_work .form-item-body textarea').val(),
                work: $('.add_work .form-item-quantity input').val(),
                work_increment: $('.add_work .form-item-quantity-type select').val()
              },
              success: function(result){
                // On success, reload work and clear the form.
                update_log('work');
                $('.add_work .form-item-body textarea').val('');
                $('.add_work .form-item-quantity input').val('');
                $('.add_work .form-item-quantity-type select').val('h');
              },
              error: function (XMLHttpRequest, textStatus, errorThrown) {
                console.log("Could not post comment.");
              }
          });
        });

      function update_log(type) {
        // Get the ticket id.
        var ticket_id = $('#burndown_task_log').data('ticket-id');

        // AJAX path.
        var path = "/burndown/api/task_log/" + ticket_id + '/' + type;

        // Update our log.
        $('#burndown_task_log').load(path);
      }
    }
  };

})(jQuery, Drupal, drupalSettings);
